/*
 * Elementary input utilities.
 *
 * Copyright (C) 2022, 2024 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdio.h>
#include <string.h>

#include "input.h"



/* Read a line from a file into the given buffer, removing any newline. */

char *read_line(FILE *fp, char *buffer, size_t bufsize)
{
    char *last;

    if (fgets(buffer, bufsize, fp) == NULL)
        return NULL;

    last = buffer + strlen(buffer) - 1;

    if ((last >= buffer) && (*last == '\n'))
        *last = '\0';

    return buffer;
}

/* Parse the text in the given region, returning details of arguments. */

void parse_line(char *start, char *end, int *num_args, char *args[], const int max_args)
{
    *num_args = 0;

    while ((start != NULL) && (start < end) && (*num_args < max_args))
    {
        args[*num_args] = start;
        (*num_args)++;

        /* NOTE: Only handling spaces as delimiters. */

        start = strchr(start, ' ');

        if (start != NULL)
        {
            *start = '\0';

            if (start < end)
                start++;
        }
    }
}

/* vim: tabstop=4 expandtab shiftwidth=4
*/
